%if 0%{?fedora} || 0%{?rhel} == 6
%global with_devel 1
%global with_bundled 0
%global with_debug 0
%global with_check 1
%global with_unit_test 1
%else
%global with_devel 0
%global with_bundled 0
%global with_debug 0
%global with_check 0
%global with_unit_test 0
%endif

%if 0%{?with_debug}
%global _dwz_low_mem_die_limit 0
%else
%global debug_package   %{nil}
%endif

%global provider        github
%global provider_tld    com
%global project         spf13
%global repo            cobra
# https://github.com/spf13/cobra
%global provider_prefix %{provider}.%{provider_tld}/%{project}/%{repo}
%global import_path     %{provider_prefix}
%global commit          8e91712f174ced10270cf66615e0a9127e7c4de5
%global shortcommit     %(c=%{commit}; echo ${c:0:7})

Name:           golang-%{provider}-%{project}-%{repo}
Version:        0
Release:        0.18.git%{shortcommit}%{?dist}
Summary:        A Commander for modern go CLI interactions
License:        ASL 2.0
URL:            https://%{provider_prefix}
Source0:        https://%{provider_prefix}/archive/%{commit}/%{repo}-%{shortcommit}.tar.gz
Patch0:         Remove-Windows-related-code.patch

# e.g. el6 has ppc64 arch without gcc-go, so EA tag is required
ExclusiveArch:  %{?go_arches:%{go_arches}}%{!?go_arches:%{ix86} x86_64 %{arm}}
# If go_compiler is not set to 1, there is no virtual provide. Use golang instead.
BuildRequires:  %{?go_compiler:compiler(go-compiler)}%{!?go_compiler:golang}

%description
Cobra is a commander providing a simple interface to create powerful modern
CLI interfaces similar to git & go tools.
In addition to providing an interface, Cobra simultaneously provides
a controller to organize your application code.

Inspired by go, go-Commander, gh and subcommand, Cobra improves on these
by providing fully posix compliant flags (including short & long versions),
nesting commands, and the ability to define your own help and usage
for any or all commands.

%if 0%{?with_devel}
%package devel
Summary:       %{summary}
BuildArch:     noarch

%if 0%{?with_check}
BuildRequires: golang(github.com/cpuguy83/go-md2man/md2man)
BuildRequires: golang(github.com/spf13/cobra)
BuildRequires: golang(github.com/spf13/pflag)
BuildRequires: golang(github.com/spf13/viper)
%endif

Requires:      golang(github.com/cpuguy83/go-md2man/md2man)
Requires:      golang(github.com/spf13/cobra)
Requires:      golang(github.com/spf13/pflag)
Requires:      golang(github.com/spf13/viper)

Provides:      golang(%{import_path}) = %{version}-%{release}
Provides:      golang(%{import_path}/cobra/cmd) = %{version}-%{release}
Provides:      golang(%{import_path}/doc) = %{version}-%{release}

%description devel
Cobra is a commander providing a simple interface to create powerful modern
CLI interfaces similar to git & go tools.
In addition to providing an interface, Cobra simultaneously provides
a controller to organize your application code.

Inspired by go, go-Commander, gh and subcommand, Cobra improves on these
by providing fully posix compliant flags (including short & long versions),
nesting commands, and the ability to define your own help and usage
for any or all commands.

This package contains library source intended for
building other packages which use import path with
%{import_path} prefix.
%endif

%if 0%{?with_unit_test}
%package unit-test
Summary:         Unit tests for %{name} package

%if 0%{?with_check}
#Here comes all BuildRequires: PACKAGE the unit tests
#in %%check section need for running
%endif

# test subpackage tests code from devel subpackage
Requires:        %{name}-devel = %{version}-%{release}

%description unit-test
%{summary}

This package contains unit tests for project
providing packages with %{import_path} prefix.
%endif

%prep
%setup -q -n %{repo}-%{commit}
%patch0 -p1

%build

%install
# source codes for building projects
%if 0%{?with_devel}
install -d -p %{buildroot}/%{gopath}/src/%{import_path}/
echo "%%dir %%{gopath}/src/%%{import_path}/." >> devel.file-list
# find all *.go but no *_test.go files and generate devel.file-list
for file in $(find . -iname "*.go" \! -iname "*_test.go") ; do
    install -d -p %{buildroot}/%{gopath}/src/%{import_path}/$(dirname $file)
    cp -pav $file %{buildroot}/%{gopath}/src/%{import_path}/$file
    echo "%%{gopath}/src/%%{import_path}/$file" >> devel.file-list
done
%endif

# testing files for this project
%if 0%{?with_unit_test}
install -d -p %{buildroot}/%{gopath}/src/%{import_path}/
# find all *_test.go files and generate unit-test.file-list
for file in $(find . -iname "*_test.go"); do
    install -d -p %{buildroot}/%{gopath}/src/%{import_path}/$(dirname $file)
    cp -pav $file %{buildroot}/%{gopath}/src/%{import_path}/$file
    echo "%%{gopath}/src/%%{import_path}/$file" >> unit-test.file-list
done
%endif

%check
%if 0%{?with_check} && 0%{?with_unit_test} && 0%{?with_devel}
%if ! 0%{?with_bundled}
export GOPATH=%{buildroot}/%{gopath}:%{gopath}
%else
export GOPATH=%{buildroot}/%{gopath}:$(pwd)/Godeps/_workspace:%{gopath}
%endif

%if ! 0%{?gotest:1}
%global gotest go test
%endif

export GOPATH=%{buildroot}/%{gopath}:%{gopath}
%gotest %{import_path}
%endif

#define license tag if not already defined
%{!?_licensedir:%global license %doc}

%if 0%{?with_devel}
%files devel -f devel.file-list
%license LICENSE.txt
%doc bash_completions.md README.md
%dir %{gopath}/src/%{provider}.%{provider_tld}/%{project}
%endif

%if 0%{?with_unit_test}
%files unit-test -f unit-test.file-list
%license LICENSE.txt
%doc bash_completions.md README.md
%endif

%changelog
* Fri Feb 10 2017 Fedora Release Engineering <releng@fedoraproject.org> - 0-0.18.git8e91712
- Rebuilt for https://fedoraproject.org/wiki/Fedora_26_Mass_Rebuild

* Thu Jul 21 2016 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0-0.17.git8e91712
- https://fedoraproject.org/wiki/Changes/golang1.7

* Sun Mar 06 2016 jchaloup <jchaloup@redhat.com> - 0-0.16.git8e91712
- Bump to upstream 8e91712f174ced10270cf66615e0a9127e7c4de5
  related: #1214769

* Sat Mar 05 2016 jchaloup <jchaloup@redhat.com> - 0-0.15.git3120920
- Bump to upstream 312092086bed4968099259622145a0c9ae280064
  related: #1214769

* Mon Feb 22 2016 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0-0.14.git8f5946c
- https://fedoraproject.org/wiki/Changes/golang1.6

* Wed Feb 03 2016 Fedora Release Engineering <releng@fedoraproject.org> - 0-0.13.git8f5946c
- Rebuilt for https://fedoraproject.org/wiki/Fedora_24_Mass_Rebuild

* Mon Aug 24 2015 jchaloup <jchaloup@redhat.com> - 0-0.12.git8f5946c
- Remove [B]R in comments, they are deleted by the patch
  related: #1214769

* Wed Aug 12 2015 Fridolin Pokorny <fpokorny@redhat.com> - 0-0.11.git8f5946c
- Update spec file to spec-2.0
  related: #1214769

* Wed Jun 17 2015 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0-0.10.git8f5946c
- Rebuilt for https://fedoraproject.org/wiki/Fedora_23_Mass_Rebuild

* Tue Jun 02 2015 jchaloup <jchaloup@redhat.com> - 0-0.9.git8f5946c
- Bump to upstream 8f5946caaeeff40a98d67f60c25e89c3525038a3
  related: #1214769

* Thu Apr 23 2015 jchaloup <jchaloup@redhat.com> - 0-0.8.git3c187e9
- Bump to upstream 3c187e904540cd62f0a197cddd6da02645a7cc5a
  related: #1214769

* Tue Mar 31 2015 jchaloup <jchaloup@redhat.com> - 0-0.7.git79bd93d
- Bump to upstream 79bd93d369fb73d640179208d4e2b1a748915567
  related: #1085881

* Wed Feb 25 2015 jchaloup <jchaloup@redhat.com> - 0-0.6.gitf8e1ec5
- Bump to upstream f8e1ec56bdd7494d309c69681267859a6bfb7549
  related: #1085881

* Wed Dec 24 2014 jchaloup <jchaloup@redhat.com> - 0-0.5.gitb1e90a7
- Bump to e1e66f7b4e667751cf530ddb6e72b79d6eeb0235
  related: #1085881

* Thu Oct 16 2014 jchaloup <jchaloup@redhat.com> - 0-0.4.gite174a40
- Bump to b1e90a7943957b51bb96a13b44b844475bcf95c0

* Sat Jun 07 2014 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0-0.3.gite174a40
- Rebuilt for https://fedoraproject.org/wiki/Fedora_21_Mass_Rebuild

* Fri Apr 04 2014 Lokesh Mandvekar <lsm5@redhat.com> 0-0.2.git
- correct tarball name

* Fri Apr 04 2014 Lokesh Mandvekar <lsm5@redhat.com> 0-0.1.git
- Initial package
